@@ -15,7 +15,7 @@ DEFAULT_CONFIG = {
         "network_disabled": False,  # Allow network for package installation
         "remove_containers": False,  # Keep container running until rm_docker()
         "auto_remove": False,
-        "image": "python:3.11-slim",  # Single multi-language image with tools
+        "image": "python:3.11-slim",  # Python base image for subprocess execution
     },
     
     # Execution settings
