@@ -35,45 +35,47 @@ class DockerSubprocessExecutor:
         self.container = self.docker_manager.get_or_create_container()
         return self.container
     
-    def execute_code(self, code: str, language: str, input_val: Any = None, 
+    def execute_code(self, code: str, language: str, input_val: Any = None,
                     timeout: Optional[int] = None) -> str:
         """
         Execute code using subprocess inside Docker container.
-        
+
         Args:
             code: Code to execute
             language: Programming language
             input_val: Input value for testing
             timeout: Execution timeout
-            
+
         Returns:
             Execution output
         """
         if timeout is None:
             timeout = settings.execution["timeout"]
-        
+
         try:
             # Validate and sanitize code
             validate_code(code, language)
             sanitized_code = sanitize_code(code, language)
-            
+
             # Prepare code for execution
             if input_val is not None:
                 prepared_code = self._prepare_test_code(sanitized_code, input_val, language)
             else:
                 prepared_code = sanitized_code
-            
-            # Ensure language is available (lazy installation)
-            self.lazy_installer.ensure_language_available(language)
 
-            # Get container
+            # Get container FIRST (before language installation)
+            # This ensures we use the same container for both installation and execution
             container = self._get_container()
 
-            # Execute code in container
+            # Ensure language is available (lazy installation)
+            # Pass the container to ensure installation happens in the same container
+            self.lazy_installer.ensure_language_available(language, container)
+
+            # Execute code in the same container
             result = self._execute_in_docker(container, prepared_code, language, timeout)
-            
+
             return result
-            
+
         except Exception as e:
             logger.error(f"Code execution failed: {e}")
             raise ExecutionError(f"Code execution failed: {e}")
