@@ -61,13 +61,14 @@ class LazyLanguageInstaller:
             }
         }
     
-    def ensure_language_available(self, language: str) -> None:
+    def ensure_language_available(self, language: str, container=None) -> None:
         """
         Ensure the specified language is available in the container.
         Install if not already installed.
 
         Args:
             language: Programming language to ensure availability
+            container: Optional specific container to use (if None, gets from docker manager)
         """
         language = language.lower()
 
@@ -77,9 +78,12 @@ class LazyLanguageInstaller:
             if language not in self._language_configs:
                 raise ExecutionError(f"Unsupported language: {language}")
 
-            # Check if language is actually available in the current container
-            docker_manager = self._get_docker_manager()
-            container = docker_manager.get_or_create_container()
+            # Use provided container or get from docker manager
+            if container is None:
+                docker_manager = self._get_docker_manager()
+                container = docker_manager.get_or_create_container()
+            else:
+                docker_manager = self._get_docker_manager()
 
             if self._test_language_availability(container, language, docker_manager):
                 # Language is available, update cache
@@ -88,8 +92,11 @@ class LazyLanguageInstaller:
                 return
 
             # Language not available, need to install
-            self._install_language(language)
+            self._install_language(language, container, docker_manager)
             self._installed_languages.add(language)
+
+            # Note: No need to update state hash as the new validation system
+            # is tolerant of development kit installations
     
     def pre_install_languages(self, languages: List[str]) -> None:
         """
@@ -114,22 +121,23 @@ class LazyLanguageInstaller:
             self._docker_manager = get_docker_manager()
         return self._docker_manager
 
-    def _install_language(self, language: str) -> None:
+    def _install_language(self, language: str, container=None, docker_manager=None) -> None:
         """Install a specific language in the container."""
         config = self._language_configs[language]
 
         print(f"[INFO] Installing {config['description']} for first-time use...")
 
         try:
-            # Get container (using fresh docker manager)
-            docker_manager = self._get_docker_manager()
-            container = docker_manager.get_or_create_container()
-            
+            # Use provided container and docker_manager or get fresh ones
+            if container is None or docker_manager is None:
+                docker_manager = self._get_docker_manager()
+                container = docker_manager.get_or_create_container()
+
             # Check if already installed
             if self._test_language_availability(container, language, docker_manager):
                 print(f"[INFO] {config['description']} already available")
                 return
-            
+
             # Install packages
             if config["packages"]:
                 self._install_packages(container, config["packages"], docker_manager)
